#
# spec file for package python-qtdatavis3d-qt5
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-qtdatavis3d-qt5
Version:        5.13.1
Release:        lp152.1.1
Summary:        Python bindings for the Qt5 Data Visualization library
License:        GPL-3.0-only
Group:          Development/Libraries/Python
URL:            https://www.riverbankcomputing.com/software/pyqtdatavisualization/intro
Source:         https://www.riverbankcomputing.com/static/Downloads/PyQtDataVisualization/%{version}/PyQtDataVisualization-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module qt5-devel}
BuildRequires:  %{python_module sip-devel >= 4.19.1}
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(Qt5DataVisualization)
Requires:       python-qt5
Requires:       python-sip(api) = %{python_sip_api_ver}

%python_subpackages

%description
PyQtDataVisualization is a set of Python bindings for the Qt5 Data
Visualization library.

%package     -n %{name}-api
Summary:        Eric API files for %{name}
Group:          Development/Libraries/Python
Provides:       %{python_module qtdatavis3d-qt5-api = %{version}}
Supplements:    packageand(eric:%{python2_prefix}-qtdatavis3d-qt5)
Supplements:    packageand(eric:python3-qtdatavis3d-qt5)
BuildArch:      noarch

%description -n %{name}-api
This package provides Qt5 Data Visualization library API files for the
Eric IDE.

%package     -n %{name}-sip
Summary:        Sip files for %{name}
Group:          Development/Tools/IDE
Provides:       %{python_module qtdatavis3d-qt5-sip = %{version}}
Supplements:    packageand(%{python2_prefix}-sip:%{python2_prefix}-qtdatavis3d-qt5)
Supplements:    packageand(python3-sip:python3-qtdatavis3d-qt5)
BuildArch:      noarch

%description -n %{name}-sip
This package contains sip files used to generate
bindings to the Qt5 Data Visualization library.

%package     -n %{name}-examples
Summary:        Examples for %{name}
Group:          Documentation/Other
Provides:       %{python_module qtdatavis3d-qt5-examples = %{version}}
BuildArch:      noarch

%description -n %{name}-examples
This package provides %{name} examples.

%prep
%setup -q -n PyQtDataVisualization-%{version}
%{python_expand mkdir build_%{$python_bin_suffix}
cp *.py build_%{$python_bin_suffix}
cp -r sip build_%{$python_bin_suffix}
}

%build
%{python_expand pushd build_%{$python_bin_suffix}
$python configure.py \
    --no-dist-info \
    --no-stubs \
    --qmake=%{_bindir}/qmake-qt5

make %{?_smp_mflags}
popd
}

%install
%{python_expand pushd build_%{$python_bin_suffix}
%make_install INSTALL_ROOT=%{buildroot}
popd
}
mkdir -p %{buildroot}%{_docdir}/%{name}
find examples -type f -executable -exec sed -i '1s=^#!%{_bindir}/\(python\|env python\)3\?=#!%{_bindir}/python3=' {} +
cp -r examples %{buildroot}%{_docdir}/%{name}

%files %{python_files}
%license LICENSE
%doc NEWS README
%dir %{python_sitearch}/PyQt5/
%{python_sitearch}/PyQt5/QtDataVisualization.so
%exclude %{_docdir}/%{name}/examples/

%files -n %{name}-api
%license LICENSE
%dir %{_datadir}/qt5/qsci/api/python/
%{_datadir}/qt5/qsci/api/python/PyQtDataVisualization.api

%files -n %{name}-sip
%license LICENSE
%{_datadir}/sip/PyQt5/QtDataVisualization/

%files -n %{name}-examples
%license LICENSE
%dir %{_docdir}/%{name}/
%{_docdir}/%{name}/examples

%changelog
* Wed Nov 13 2019 Todd R <toddrme2178@gmail.com>
- Update to 5.13.1
  * Added support for SIP v5.
* Fri Jul 12 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.13.0
  * Bindings updated for QtDataVis 5.13.0.
* Wed Feb 27 2019 Todd R <toddrme2178@gmail.com>
- Make eric api files supplement eric.
- Make sip api files supplement sip.
- Fix sip api dependency.
* Thu Feb 21 2019 Todd R <toddrme2178@gmail.com>
- Consistency fixes with the other python-qt5 add-on packages.
* Thu Feb 21 2019 Todd R <toddrme2178@gmail.com>
- Update to 5.12
  * Updated for Qt v5.12.1.
- Build both python2 and python3 flavors in a single spec file.
* Mon Oct 22 2018 Christophe Giboudeaux <christophe@krop.fr>
- Run spec-cleaner
- Update to 5.11.3. Changes since 5.10.1:
  * Fixed all signal signatures.
  * Add support for recent Qt versions.
* Tue Apr 17 2018 termim@gmail.com
- Update to 5.10.1
  * Added support for Qt Charts v5.10.1.
* Fri Jan 26 2018 aloisio@gmx.com
- Update to 5.10
  * Added support for Qt Data Visualization v5.10.0.
  version 5.9.2
  * Added support for Qt Data Visualization v5.9.3.
  version 5.9.1
  * Added support for Qt Data Visualization v5.9.2.
  version 5.9
  * Added support for Qt Data Visualization v5.9.0 and v5.9.1.
* Wed Feb 15 2017 termim@gmail.com
- Update to 5.8
* Tue Jan  3 2017 termim@gmail.com
- Update to 5.7.1
* Fri Jul 29 2016 termim@gmail.com
- Initial checkin v.2.0.1
